pub struct BasicCallOptions { /* private fields */ }Expand description
A call option class that is used to control how calls are handled
You can define the timeout, and the message versions
Implementations
Sourceimpl BasicCallOptions
impl BasicCallOptions